@@ -2580,4 +2580,23 @@ def ClassifyBehaviorMultiVideos(data, bodyparts_list, dimensions = 2,distance=28
     cluster_df                         = pd.DataFrame.from_dict(cluster_labels)
 
 
-    return cluster_df, cluster_coord ,fitted_model
\ No newline at end of file
+    return cluster_df, cluster_coord ,fitted_model
+
+def dendrogram(model, **kwargs):
+    from scipy.cluster.hierarchy import dendrogram
+
+    counts = np.zeros(model.children_.shape[0])
+    n_samples = len(model.labels_)
+
+    for i, merge in enumerate(model.children_):
+        current_count = 0
+        for child_idx in merge:
+            if child_idx < n_samples:
+                current_count += 1  # leaf node
+            else:
+                current_count += counts[child_idx - n_samples]
+        counts[i] = current_count
+
+    linkage_matrix = np.column_stack([model.children_, model.distances_, counts]).astype(float)
+
+    dendrogram(linkage_matrix, truncate_mode="level", p=3,leaf_rotation=90, leaf_font_size=10)
\ No newline at end of file
